﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;

namespace BastaAdministrator
{
    public interface IAsyncCommand : ICommand
    {
        Task ExecuteAsync(object parameter);
    }
    public class DelegateCommand : IAsyncCommand
    {
        private readonly Func<object,Task> _execute;

        private readonly Func<object, bool> _canExecute;

        public DelegateCommand(Func<object,Task> execute,
            Func<object, bool> canExecute = null)
        {
            this._execute = execute;
            this._canExecute = canExecute;
        }

        public bool CanExecute(object parameter)
        {
            return _canExecute == null || _canExecute(parameter);
        }

        public void RaiseCanExecuteChanged()
        {
            var handler = CanExecuteChanged;
            if (handler != null)
            {
                handler(this, EventArgs.Empty);
            }
        }

        public event EventHandler CanExecuteChanged;

        public Task ExecuteAsync(object parameter)
        {
            return _execute(parameter);
        }

        public async void Execute(object parameter)
        {
            await _execute(parameter);
        }
    }
}
