﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace UnitTestProject1
{
    using System.Collections.Generic;
    using System.Threading;
    using System.Threading.Tasks;

    using BastaAdministrator.DataProvider;
    using BastaAdministrator.ViewModel;

    using Moq;

    [TestClass]
    public class UnitTest1
    {
        [TestMethod]
        public async Task LoadMethodShouldFillSpeakersAndSessions()
        {
            var speakers = new List<string> { "Timo", "Daniel", "Thomas" };
            var sessions = new List<string> { "AsyncUI", "AngularJs" };

            var speakerProviderMock = new Mock<ISpeakerProvider>();
            speakerProviderMock.Setup(x=>x.LoadSpeakersAsync())
                .Returns(Task.Factory.StartNew(
                    () =>
                    {
                        Thread.Sleep(2000);
                        return speakers;
                    }));

              var sessionProviderMock = new Mock<ISessionProvider>();
            sessionProviderMock.Setup(x=>x.LoadSessionsAsync())
                .Returns(Task.FromResult(sessions));

            var vm=new MainViewModel(speakerProviderMock.Object,
                sessionProviderMock.Object);

            Assert.AreEqual(0, vm.Speakers.Count);
            Assert.AreEqual(0, vm.Sessions.Count);
            await vm.LoadCommand.ExecuteAsync(null);
            Assert.AreEqual(3, vm.Speakers.Count);
            Assert.AreEqual(2, vm.Sessions.Count);
        }

     
    }
}
